﻿$toolsPath = Split-Path $MyInvocation.MyCommand.Definition
function Accept-Eula() {

$tools = `
"AccessChk",        "Active Directory Explorer", "ADInsight",  "Autologon",       "AutoRuns",
"BGInfo",           "CacheSet",                  "ClockRes",   "Coreinfo",        "Ctrl2cap",
"DbgView",          "Desktops",                  "Disk2Vhd",   "Diskmon",         "DiskView",
"Du",               "EFSDump",                   "FindLinks",  "Handle",          "Hex2Dec",
"Junction",         "LdmDump",                   "ListDLLs",   "LoadOrder",       "Movefile",
"PageDefrag",       "PendMove",                  "PipeList",   "Portmon",         "ProcDump",
"Process Explorer", "Process Monitor",           "PsExec",     "psfile",          "PsGetSid",
"PsInfo",           "PsKill",                    "PsList",     "PsLoggedon",      "PsLoglist",
"PsPasswd",         "PsService",                 "PsShutdown", "PsSuspend",       "RamMap",
"RegDelNull",       "Regjump",                   "Regsize",    "RootkitRevealer", "Share Enum",
"ShellRunas",       "SigCheck",                  "Streams",    "Strings",         "Sync",
"System Monitor",   "TCPView",                   "VMMap",      "VolumeID",        "Whois",
"Winobj",           "ZoomIt"

    $root_path = "HKCU:\SOFTWARE\Sysinternals"
    mkdir "$root_path" -ea 0 | Out-Null
    foreach($tool in $tools) {
        mkdir "$root_path\$tool" -ea 0 | Out-Null
        New-ItemProperty -Path "$root_path\$tool" -Name EulaAccepted -Value 1 -Force | Out-Null
    }

    $vt = "$root_path\SigCheck\VirusTotal"
    mkdir $vt -ea 0 | Out-Null
    New-ItemProperty -Path $vt -Name VirusTotalTermsAccepted -Value 1 -Force | Out-Null
}

function Is-NanoServer() {
  # This would be true for both nano servers, and IoT devices.
  if ($PSVersionTable.PSEdition -ne 'Core') { return $false }

  # 143 = Datacenter nano server
  # 144 = Standard nano server
  $sku = (Get-CimInstance -ClassName Win32_OperatingSystem).OperatingSystemSKU
  return ($sku -eq 143) -or ($sku -eq 144);
}


$pp = Get-PackageParameters
$installDir = $toolsPath
if ($pp.InstallDir -or $pp.InstallationPath ) { $InstallDir = $pp.InstallDir + $pp.InstallationPath }
Write-Host "Sysinternals Suite is going to be installed in '$installDir'"

$packageArgs = @{
  packageName    = 'sysinternals'
  url            = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)\files\SysinternalsSuite.zip"
  checksum       = '813167a261ee2c97e5e0a2b89a4745e1a60c1543b8f7ed8bb12b582f659aafea'
  checksumType   = 'sha256'
  unzipLocation  = $installDir
}
Install-ChocolateyZipPackage @packageArgs
Accept-Eula
if ($installDir -ne $toolsPath) { Install-ChocolateyPath $installDir }
if (Is-NanoServer) {
  $packageArgs.url = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)\files\SysinternalsSuite-Nano.zip"
  $packageArgs.checksum = 'a01b0097adee42ba1f075cfd416bf085dac860a3381ed7cb2549a2c81f273789'
 }

$old_path = 'c:\sysinternals'
if ((Test-Path $old_path) -and ($installDir -ne $old_path)) {
    Write-Warning "Clean up older versions of this install at c:\sysinternals"
}
